# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ostorlab/agent/message/proto/v3/fingerprint/file/ios/backend/backend.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJostorlab/agent/message/proto/v3/fingerprint/file/ios/backend/backend.proto\x12<ostorlab.agent.message.proto.v3.fingerprint.file.ios.backend\"\xe5\x01\n\x08Location\x12\x11\n\tcontinent\x18\x01 \x01(\t\x12\x16\n\x0e\x63ontinent_code\x18\x02 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x13\n\x0bregion_name\x18\x06 \x01(\t\x12\x0c\n\x04\x63ity\x18\x07 \x01(\t\x12\x0b\n\x03zip\x18\x08 \x01(\t\x12\x10\n\x08latitude\x18\t \x01(\x02\x12\x11\n\tlongitude\x18\n \x01(\x02\x12\x10\n\x08timezone\x18\x0b \x01(\t\x12\x10\n\x08\x64istrict\x18\x0c \x01(\t\"\x86\x01\n\x02Ip\x12\x12\n\nip_address\x18\x01 \x02(\t\x12\x12\n\x07version\x18\x02 \x01(\x05:\x01\x34\x12X\n\x08location\x18\x03 \x01(\x0b\x32\x46.ostorlab.agent.message.proto.v3.fingerprint.file.ios.backend.Location\"\x95\x01\n\x07Message\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tbundle_id\x18\x02 \x02(\t\x12\x0c\n\x04host\x18\x03 \x02(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12M\n\x03ips\x18\x05 \x03(\x0b\x32@.ostorlab.agent.message.proto.v3.fingerprint.file.ios.backend.Ip')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ostorlab.agent.message.proto.v3.fingerprint.file.ios.backend.backend_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOCATION._serialized_start=141
  _LOCATION._serialized_end=370
  _IP._serialized_start=373
  _IP._serialized_end=507
  _MESSAGE._serialized_start=510
  _MESSAGE._serialized_end=659
# @@protoc_insertion_point(module_scope)
