"""Module for the root command: scan."""
from ostorlab.cli.scan.scan import scan
from ostorlab.cli.scan.run import run
from ostorlab.cli.scan.stop import stop
from ostorlab.cli.scan.list import list as scan_list
