# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ostorlab/scanner/proto/scan/_location/startAgentScan.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ostorlab.scanner.proto.assets import ip_pb2 as ostorlab_dot_scanner_dot_proto_dot_assets_dot_ip__pb2
from ostorlab.scanner.proto.assets import v4_pb2 as ostorlab_dot_scanner_dot_proto_dot_assets_dot_v4__pb2
from ostorlab.scanner.proto.assets import v6_pb2 as ostorlab_dot_scanner_dot_proto_dot_assets_dot_v6__pb2
from ostorlab.scanner.proto.assets import domain_name_pb2 as ostorlab_dot_scanner_dot_proto_dot_assets_dot_domain__name__pb2
from ostorlab.scanner.proto.assets import file_pb2 as ostorlab_dot_scanner_dot_proto_dot_assets_dot_file__pb2
from ostorlab.scanner.proto.assets import aab_pb2 as ostorlab_dot_scanner_dot_proto_dot_assets_dot_aab__pb2
from ostorlab.scanner.proto.assets import apk_pb2 as ostorlab_dot_scanner_dot_proto_dot_assets_dot_apk__pb2
from ostorlab.scanner.proto.assets import ipa_pb2 as ostorlab_dot_scanner_dot_proto_dot_assets_dot_ipa__pb2
from ostorlab.scanner.proto.assets import source_pb2 as ostorlab_dot_scanner_dot_proto_dot_assets_dot_source__pb2
from ostorlab.scanner.proto.assets import agent_pb2 as ostorlab_dot_scanner_dot_proto_dot_assets_dot_agent__pb2
from ostorlab.scanner.proto.assets import network_pb2 as ostorlab_dot_scanner_dot_proto_dot_assets_dot_network__pb2
from ostorlab.scanner.proto.assets import link_pb2 as ostorlab_dot_scanner_dot_proto_dot_assets_dot_link__pb2
from ostorlab.scanner.proto.assets import android_store_pb2 as ostorlab_dot_scanner_dot_proto_dot_assets_dot_android__store__pb2
from ostorlab.scanner.proto.assets import ios_store_pb2 as ostorlab_dot_scanner_dot_proto_dot_assets_dot_ios__store__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:ostorlab/scanner/proto/scan/_location/startAgentScan.proto\x12\x34ostorlab.scanner.proto.scan._location.startAgentScan\x1a&ostorlab/scanner/proto/assets/ip.proto\x1a&ostorlab/scanner/proto/assets/v4.proto\x1a&ostorlab/scanner/proto/assets/v6.proto\x1a/ostorlab/scanner/proto/assets/domain_name.proto\x1a(ostorlab/scanner/proto/assets/file.proto\x1a\'ostorlab/scanner/proto/assets/aab.proto\x1a\'ostorlab/scanner/proto/assets/apk.proto\x1a\'ostorlab/scanner/proto/assets/ipa.proto\x1a*ostorlab/scanner/proto/assets/source.proto\x1a)ostorlab/scanner/proto/assets/agent.proto\x1a+ostorlab/scanner/proto/assets/network.proto\x1a(ostorlab/scanner/proto/assets/link.proto\x1a\x31ostorlab/scanner/proto/assets/android_store.proto\x1a-ostorlab/scanner/proto/assets/ios_store.proto\"0\n\x03\x41rg\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04type\x18\x02 \x02(\t\x12\r\n\x05value\x18\x03 \x01(\x0c\"\xcf\x01\n\x05\x41gent\x12\x0b\n\x03key\x18\x01 \x02(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x10\n\x08replicas\x18\x03 \x01(\x05\x12G\n\x04\x61rgs\x18\x04 \x03(\x0b\x32\x39.ostorlab.scanner.proto.scan._location.startAgentScan.Arg\x12\x0c\n\x04\x63\x61ps\x18\x05 \x03(\t\x12\x1f\n\x17\x63yclic_processing_limit\x18\x06 \x01(\r\x12\x1e\n\x16\x64\x65pth_processing_limit\x18\x07 \x01(\r\"C\n\x05Links\x12:\n\x05links\x18\x01 \x03(\x0b\x32+.ostorlab.scanner.proto.assets.link.Message\"\xa7\x08\n\x07Message\x12\x19\n\x11reference_scan_id\x18\x01 \x02(\x05\x12K\n\x06\x61gents\x18\x02 \x03(\x0b\x32;.ostorlab.scanner.proto.scan._location.startAgentScan.Agent\x12\x0b\n\x03key\x18\x11 \x01(\t\x12\x37\n\x02ip\x18\x03 \x01(\x0b\x32).ostorlab.scanner.proto.assets.ip.MessageH\x00\x12\x39\n\x04ipv4\x18\x04 \x01(\x0b\x32).ostorlab.scanner.proto.assets.v4.MessageH\x00\x12\x39\n\x04ipv6\x18\x05 \x01(\x0b\x32).ostorlab.scanner.proto.assets.v6.MessageH\x00\x12;\n\x04\x66ile\x18\x06 \x01(\x0b\x32+.ostorlab.scanner.proto.assets.file.MessageH\x00\x12\x39\n\x03\x61\x61\x62\x18\x07 \x01(\x0b\x32*.ostorlab.scanner.proto.assets.aab.MessageH\x00\x12\x39\n\x03\x61pk\x18\x08 \x01(\x0b\x32*.ostorlab.scanner.proto.assets.apk.MessageH\x00\x12\x39\n\x03ipa\x18\t \x01(\x0b\x32*.ostorlab.scanner.proto.assets.ipa.MessageH\x00\x12?\n\x06source\x18\n \x01(\x0b\x32-.ostorlab.scanner.proto.assets.source.MessageH\x00\x12I\n\x0b\x64omain_name\x18\x0b \x01(\x0b\x32\x32.ostorlab.scanner.proto.assets.domain_name.MessageH\x00\x12=\n\x05\x61gent\x18\x0c \x01(\x0b\x32,.ostorlab.scanner.proto.assets.agent.MessageH\x00\x12\x41\n\x07network\x18\r \x01(\x0b\x32..ostorlab.scanner.proto.assets.network.MessageH\x00\x12L\n\x05links\x18\x0e \x01(\x0b\x32;.ostorlab.scanner.proto.scan._location.startAgentScan.LinksH\x00\x12M\n\randroid_store\x18\x0f \x01(\x0b\x32\x34.ostorlab.scanner.proto.assets.android_store.MessageH\x00\x12\x45\n\tios_store\x18\x10 \x01(\x0b\x32\x30.ostorlab.scanner.proto.assets.ios_store.MessageH\x00\x12\x0f\n\x07scan_id\x18\x12 \x01(\x05\x42\x07\n\x05\x61sset')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ostorlab.scanner.proto.scan._location.startAgentScan_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ARG._serialized_start=722
  _ARG._serialized_end=770
  _AGENT._serialized_start=773
  _AGENT._serialized_end=980
  _LINKS._serialized_start=982
  _LINKS._serialized_end=1049
  _MESSAGE._serialized_start=1052
  _MESSAGE._serialized_end=2115
# @@protoc_insertion_point(module_scope)
