# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ostorlab/agent/message/proto/v3/report/cve/cve.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4ostorlab/agent/message/proto/v3/report/cve/cve.proto\x12*ostorlab.agent.message.proto.v3.report.cve\"\xc1\x02\n\x07Message\x12\x0e\n\x06\x63ve_id\x18\x01 \x01(\t\x12\x43\n\x07targets\x18\x02 \x03(\x0b\x32\x32.ostorlab.agent.message.proto.v3.report.cve.Target\x12\x0b\n\x03\x63we\x18\x03 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12I\n\nreferences\x18\x05 \x03(\x0b\x32\x35.ostorlab.agent.message.proto.v3.report.cve.Reference\x12\x45\n\x0b\x63vss_scores\x18\x06 \x01(\x0b\x32\x30.ostorlab.agent.message.proto.v3.report.cve.CVSS\x12\x16\n\x0epublished_date\x18\x07 \x01(\x04\x12\x15\n\rmodified_date\x18\x08 \x01(\x04\"\xc8\x01\n\x04\x43VSS\x12?\n\x03v31\x18\x01 \x01(\x0b\x32\x32.ostorlab.agent.message.proto.v3.report.cve.CVSSv3\x12?\n\x03v30\x18\x02 \x01(\x0b\x32\x32.ostorlab.agent.message.proto.v3.report.cve.CVSSv3\x12>\n\x02v2\x18\x03 \x01(\x0b\x32\x32.ostorlab.agent.message.proto.v3.report.cve.CVSSv2\"\xdb\x05\n\x06\x43VSSv2\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rvector_string\x18\x02 \x01(\t\x12\x1e\n\x16\x63onfidentiality_impact\x18\x03 \x01(\t\x12\x18\n\x10integrity_impact\x18\x04 \x01(\t\x12\x1b\n\x13\x61vailability_impact\x18\x05 \x01(\t\x12\x12\n\nbase_score\x18\x06 \x01(\x02\x12\x19\n\x11remediation_level\x18\x07 \x01(\t\x12\x19\n\x11report_confidence\x18\x08 \x01(\t\x12\x16\n\x0etemporal_score\x18\t \x01(\x02\x12#\n\x1b\x63onfidentiality_requirement\x18\n \x01(\t\x12\x1d\n\x15integrity_requirement\x18\x0b \x01(\t\x12 \n\x18\x61vailability_requirement\x18\x0c \x01(\t\x12\x1b\n\x13\x65nvironmental_score\x18\r \x01(\x02\x12\x15\n\raccess_vector\x18\x0e \x01(\t\x12\x19\n\x11\x61\x63\x63\x65ss_complexity\x18\x0f \x01(\t\x12\x16\n\x0e\x61uthentication\x18\x10 \x01(\t\x12\x16\n\x0e\x65xploitability\x18\x11 \x01(\t\x12#\n\x1b\x63ollateral_damage_potential\x18\x12 \x01(\t\x12\x1b\n\x13target_distribution\x18\x13 \x01(\t\x12\x14\n\x0cimpact_score\x18\x14 \x01(\x02\x12\x1c\n\x14\x65xploitability_score\x18\x15 \x01(\x02\x12\x15\n\rac_insuf_info\x18\x16 \x01(\x08\x12\x1c\n\x14obtain_all_privilege\x18\x17 \x01(\x08\x12\x1d\n\x15obtain_user_privilege\x18\x18 \x01(\x08\x12\x1e\n\x16obtain_other_privilege\x18\x19 \x01(\x08\x12!\n\x19user_interaction_required\x18\x1a \x01(\x08\"\xa0\x07\n\x06\x43VSSv3\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rvector_string\x18\x02 \x01(\t\x12\x1e\n\x16\x63onfidentiality_impact\x18\x03 \x01(\t\x12\x18\n\x10integrity_impact\x18\x04 \x01(\t\x12\x1b\n\x13\x61vailability_impact\x18\x05 \x01(\t\x12\x12\n\nbase_score\x18\x06 \x01(\x02\x12\x19\n\x11remediation_level\x18\x07 \x01(\t\x12\x19\n\x11report_confidence\x18\x08 \x01(\t\x12\x16\n\x0etemporal_score\x18\t \x01(\x02\x12#\n\x1b\x63onfidentiality_requirement\x18\n \x01(\t\x12\x1d\n\x15integrity_requirement\x18\x0b \x01(\t\x12 \n\x18\x61vailability_requirement\x18\x0c \x01(\t\x12\x1b\n\x13\x65nvironmental_score\x18\r \x01(\x02\x12\x15\n\rattack_vector\x18\x0e \x01(\t\x12\x19\n\x11\x61ttack_complexity\x18\x0f \x01(\t\x12\x1b\n\x13privileges_required\x18\x10 \x01(\t\x12\x18\n\x10user_interaction\x18\x11 \x01(\t\x12\r\n\x05scope\x18\x12 \x01(\t\x12\x15\n\rbase_severity\x18\x13 \x01(\t\x12\x1d\n\x15\x65xploit_code_maturity\x18\x14 \x01(\t\x12\x19\n\x11temporal_severity\x18\x15 \x01(\t\x12\x1e\n\x16modified_attack_vector\x18\x16 \x01(\t\x12\"\n\x1amodified_attack_complexity\x18\x17 \x01(\t\x12$\n\x1cmodified_privileges_required\x18\x18 \x01(\t\x12!\n\x19modified_user_interaction\x18\x19 \x01(\t\x12\x16\n\x0emodified_scope\x18\x1a \x01(\t\x12\'\n\x1fmodified_confidentiality_impact\x18\x1b \x01(\t\x12!\n\x19modified_integrity_impact\x18\x1c \x01(\t\x12$\n\x1cmodified_availability_impact\x18\x1d \x01(\t\x12\x1e\n\x16\x65nvironmental_severity\x18\x1e \x01(\t\x12\x14\n\x0cimpact_score\x18\x1f \x01(\x02\x12\x1c\n\x14\x65xploitability_score\x18  \x01(\x02\"6\n\tReference\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\"V\n\x0cVersionMatch\x12\r\n\x05start\x18\x01 \x01(\t\x12\x15\n\rstart_include\x18\x02 \x01(\x08\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\x13\n\x0b\x65nd_include\x18\x04 \x01(\x08\"\x86\x02\n\x08\x43peMatch\x12\x0c\n\x04part\x18\x01 \x01(\t\x12\x0e\n\x06vendor\x18\x02 \x01(\t\x12\x0f\n\x07product\x18\x03 \x01(\t\x12I\n\x07version\x18\x04 \x01(\x0b\x32\x38.ostorlab.agent.message.proto.v3.report.cve.VersionMatch\x12\x0e\n\x06update\x18\x05 \x01(\t\x12\x0f\n\x07\x65\x64ition\x18\x06 \x01(\t\x12\x10\n\x08language\x18\x07 \x01(\t\x12\x12\n\nsw_edition\x18\x08 \x01(\t\x12\n\n\x02sw\x18\t \x01(\t\x12\n\n\x02hw\x18\n \x01(\t\x12\r\n\x05other\x18\x0b \x01(\t\x12\x12\n\nvulnerable\x18\x0c \x01(\x08\"S\n\x06Target\x12I\n\x0b\x63pe_matches\x18\x01 \x03(\x0b\x32\x34.ostorlab.agent.message.proto.v3.report.cve.CpeMatch')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ostorlab.agent.message.proto.v3.report.cve.cve_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MESSAGE._serialized_start=101
  _MESSAGE._serialized_end=422
  _CVSS._serialized_start=425
  _CVSS._serialized_end=625
  _CVSSV2._serialized_start=628
  _CVSSV2._serialized_end=1359
  _CVSSV3._serialized_start=1362
  _CVSSV3._serialized_end=2290
  _REFERENCE._serialized_start=2292
  _REFERENCE._serialized_end=2346
  _VERSIONMATCH._serialized_start=2348
  _VERSIONMATCH._serialized_end=2434
  _CPEMATCH._serialized_start=2437
  _CPEMATCH._serialized_end=2699
  _TARGET._serialized_start=2701
  _TARGET._serialized_end=2784
# @@protoc_insertion_point(module_scope)
